[![Build Status](https://travis-ci.com/dist-computing/cs107-FinalProject.svg?token=psyyZA7ALxqWvs9wtjPk&branch=main)](https://travis-ci.com/dist-computing/cs107-FinalProject)
[![codecov](https://codecov.io/gh/dist-computing/cs107-FinalProject/branch/main/graph/badge.svg?token=LGYNF0ZSMA)](https://codecov.io/gh/dist-computing/cs107-FinalProject)
# Final Project Repo for Group 31

## Find our documentation on our website
[aad.fer.me](https://aad.fer.me)

Names:
* Matheus C. Fernandes
* Haipeng Lin
* Ben Manning
* *TF: Johnathan Jiang

## Git Workflow
* Create your own branch in `feature/name`
* Commit changes and resolve merge conflicts by `git merge main`
* Submit pull request to `main`
* Approve and merge to `main` 

### Collaborative workflow in Deepnote
To facilitate coding, we used a shared deepnote project to create shared commits under the `group/*` branches.

* Use Jupyter Notebook `%%writefile` to save into the `cs107-FinalProject` folder in Deepnote;
* Use the terminal to `git commit` staged files as appropriate;
* Create the pull request and ask another teammate for approval.
